/**
 * @fileoverview vue文件默认导入必须为大驼峰命名
 * @author fwz
 */
"use strict";

//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------

/** @type {import('eslint').Rule.RuleModule} */
module.exports = {
  meta: {
    type: "suggestion", //   `problem`, `suggestion`, or `layout`
    docs: {
      description: "vue文件默认导入必须为大驼峰命名",
      recommended: false,
      url: null, // URL to the documentation page for this rule
    },
    messages: {
      named: "vue文件默认导入必须为大驼峰命名",
    },
    fixable: "code", // Or `code` or `whitespace`
    schema: [], // Add a schema if the rule has options
  },

  create(context) {
    function getImportDefaultSpecifier(specifiers = []) {
      let result = undefined;
      for (const el of specifiers) {
        if (el.type === "ImportDefaultSpecifier") {
          result = el;
          break;
        }
      }
      return result;
    }

    function isVueComponentImport(source) {
      return /\.vue$/.test(source.value);
    }

    function generateFixedImportText(node){
      const defaultSpecifier = getImportDefaultSpecifier(node.specifiers);
      const localName = defaultSpecifier.local.name
      const upName = localName[0].toUpperCase() + localName.substr(1)
      return `import ${upName} from '${node.source.value}'`
    }

    return {
      // visitor functions for different types of nodes
      ImportDeclaration(node) {
        if (isVueComponentImport(node.source)) {
          const defaultSpecifier = getImportDefaultSpecifier(node.specifiers);
          if (defaultSpecifier) {
            if (!/^[A-Z]/.test(defaultSpecifier.local.name)) {
              return context.report({
                node,
                messageId: "named",
                fix(fixer) {
                  return fixer.replaceTextRange(
                    node.range,
                    generateFixedImportText(node)
                  );
                },
              });
            }
          }
        }
      },
    };
  },
};
